Crate http3_datagram

Crate http3_datagram 

Modules

client
client API
datagram
datagram_handler
Traits which define the user API for datagrams. These traits are implemented for the client and server types in the http3 crate.
quic_traits
QUIC Transport traits
server
server API

Enums

ConnectionErrorIncoming
Error type to communicate that the quic connection was closed