pub enum SendDatagramErrorIncoming {
NotAvailable,
TooLarge,
ConnectionError(ConnectionErrorIncoming),
}Expand description
Types of errors when sending a datagram.
Variants
NotAvailable
The peer is not accepting datagrams
This can be because the peer does not support it or disabled it or any other reason.
TooLarge
The datagram is too large to send
ConnectionError(ConnectionErrorIncoming)
Connection error